
# Slot: participates in


holds between a continuant and a process, where the continuant is somehow involved in the process

URI: [biolink:participates_in](https://w3id.org/biolink/vocab/participates_in)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [Occurrent](Occurrent.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children

 *  [actively involved in](actively_involved_in.md)
 *  [enables](enables.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | RO:0000056 |
|  | | BFO:0000056 |
|  | | RTXKG1:participates_in |
| **Narrow Mappings:** | | DRUGBANK:pathway |
|  | | HMDB:in_pathway |
|  | | LOINC:is_given_pharmaceutical_substance_for |
|  | | NCIT:R130 |
|  | | NCIT:R37 |
|  | | NCIT:R131 |
|  | | NCIT:R51 |
|  | | NCIT:R53 |
|  | | OBI:0000295 |
|  | | RO:0002216 |
|  | | RO:0002505 |
|  | | RO:0002565 |
|  | | SNOMED:has_direct_device |

